#
# spec file for package qrca
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf6_version 6.8.0
%define qt6_version 6.6.0

%bcond_without released
Name:           qrca
Version:        25.04.3
Release:        1.1
Summary:        QR code scanner for Plasma
License:        GPL-3.0-or-later
URL:            https://apps.kde.org/qrca/
Source0:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
BuildRequires:  cmake(KF6Config) >= %{kf6_version}
BuildRequires:  cmake(KF6Contacts) >= %{kf6_version}
BuildRequires:  cmake(KF6CoreAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6Crash) >= %{kf6_version}
BuildRequires:  cmake(KF6I18n) >= %{kf6_version}
BuildRequires:  cmake(KF6KIO) >= %{kf6_version}
BuildRequires:  cmake(KF6Kirigami) >= %{kf6_version}
BuildRequires:  cmake(KF6NetworkManagerQt) >= %{kf6_version}
BuildRequires:  cmake(KF6Notifications) >= %{kf6_version}
BuildRequires:  cmake(KF6Prison) >= %{kf6_version}
BuildRequires:  cmake(KF6Service) >= %{kf6_version}
BuildRequires:  cmake(Qt6Core) >= %{qt6_version}
BuildRequires:  cmake(Qt6Gui) >= %{qt6_version}
BuildRequires:  cmake(Qt6Multimedia) >= %{qt6_version}
BuildRequires:  cmake(Qt6Quick) >= %{qt6_version}
BuildRequires:  cmake(Qt6QuickControls2) >= %{qt6_version}
BuildRequires:  cmake(Qt6Svg) >= %{qt6_version}
BuildRequires:  cmake(Qt6Test) >= %{qt6_version}
Requires:       kf6-kconfig-imports >= %{kf6_version}
Requires:       kf6-kirigami-imports >= %{kf6_version}
Requires:       kf6-prison-imports >= %{kf6_version}
Requires:       kirigami-addons6
Requires:       qt6-declarative-imports >= %{qt6_version}
Requires:       qt6-multimedia-imports >= %{qt6_version}

%description
Qrca is a simple application for Plasma Desktop and Plasma Mobile that lets
you scan many barcode formats and create your own QR code images.

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf6

%kf6_build

%install
%kf6_install

# E: env-script-interpreter
sed -i '/env xdg-open/d' %{buildroot}%{_kf6_applicationsdir}/org.kde.qrca*.desktop

%find_lang %{name}

%check

%files
%license LICENSES/*
%doc README.md
%{_kf6_bindir}/qrca
%{_kf6_applicationsdir}/org.kde.qrca.desktop
%{_kf6_applicationsdir}/org.kde.qrca.wifi.desktop
%{_kf6_appstreamdir}/org.kde.qrca.appdata.xml
%{_kf6_iconsdir}/hicolor/scalable/apps/org.kde.qrca.svg

%files lang -f %{name}.lang

%changelog
* Tue Jul  1 2025 Christophe Marin <christophe@krop.fr>
- Update to 25.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/25.04.3/
- No code change since 25.04.2
* Tue Jun  3 2025 Christophe Marin <christophe@krop.fr>
- Update to 25.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/25.04.2/
- No code change since 25.04.1
* Wed May  7 2025 Christophe Marin <christophe@krop.fr>
- Update to 25.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/25.04.1/
- Changes since 25.04.0:
  * metainfo: Add screenshots from product-screenshots
* Mon Apr 14 2025 Christophe Marin <christophe@krop.fr>
- Update to 25.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/25.04.0/
- No code change since 25.03.90
* Sat Mar 29 2025 Christophe Marin <christophe@krop.fr>
- Update to 25.03.90
  * New feature release
* Wed Jan 29 2025 Christophe Marin <christophe@krop.fr>
- Init qrca
